@@ -1,7 +1,7 @@
 from .base_enum import BaseEnum
 
 
-class SearchAutoMapper(BaseEnum):
+class ESearchAutoMapper(BaseEnum):
     BOTH = True
     AI = False
     NO_AI = None
